
.. module:: dynts.web.flot

==========================
Flot Data
==========================

.. autoclass:: dynts.web.flot.MultiPlot
   :members:
   :member-order: bysource
   
   
.. autoclass:: dynts.web.flot.Flot
   :members:
   :member-order: bysource
   